###################################################
###   R scripts for the generation of Figure 2  ###
###              Julie Callanan                 ### 
###################################################

setwd('/lit_review_extraction_methods/')

######### Install packages #########

#install.packages('stringr')
library('stringr')

#install.packages('dplyr')
library('dplyr')

#install.packages('ggplot2')
library('ggplot2')

#install.packages('reshape2')
library('reshape2')

#install.packages('RColorBrewer')
library('RColorBrewer')

install.packages("devtools")
devtools::install_github("renkun-ken/formattable")
library('formattable')

install.packages('htmltools')
library("htmltools")

install.packages('webshot')
library("webshot")
webshot::install_phantomjs()

######### Package citations and R version ######### 

citation() 
#To find package citations.

R.version
#R version 3.5.3 (2019-03-11)

######### Sort and analyse the necessary table ######### 
read.csv('small_methods_tbl.csv', header = T, stringsAsFactors = F) -> methods_tbl

methods_tbl[is.na(methods_tbl)] <- ""

tbl1 <- formattable(methods_tbl, list(
  PEG = formatter("span",
                  style = x ~ style(color = ifelse(x, "green", "red")),
                  x ~ icontext(ifelse(x, "ok", "remove"))),
  MDA = formatter("span",
                  style = x ~ style(color = ifelse(x, "green", "red")),
                  x ~ icontext(ifelse(x, "ok", "remove"))),
  RT = formatter("span",
                 style = x ~ style(color = ifelse(x, "green", "red")),
                 x ~ icontext(ifelse(x, "ok", "remove"))),
  TFF = formatter("span",
                 style = x ~ style(color = ifelse(x, "green", "red")),
                 x ~ icontext(ifelse(x, "ok", "remove"))),
  CsCl = formatter("span",
                   style = x ~ style(color = ifelse(x, "green", "red")),
                   x ~ icontext(ifelse(x, "ok", "remove"))),
  Chloroform = formatter("span",
                         style = x ~ style(color = ifelse(x, "green", "red")),
                         x ~ icontext(ifelse(x, "ok", "remove"))),
  TFF = formatter("span",
                  style = x ~ style(color = ifelse(x, "green", "red")),
                  x ~ icontext(ifelse(x, "ok", "remove"))),
  RNA_viruses = formatter("span",
                          style = x ~ style(color = ifelse(x, "green", "red")),
                          x ~ icontext(ifelse(x, "ok", "remove")))))

tbl1

#Add ifelse(x, "Yes", "No") after the icontext line to add a 'Yes' and 'No' to the symbols - removed to clean up the table a little bit :)

#Save html file as .jpeg as colour lost in .pdf format 
export_formattable <- function(tbl1, file, width = "100%", height = NULL, 
                               background = "white", delay = 0.2)
{
  w <- as.htmlwidget(tbl1, width = width, height = height)
  path <- html_print(w, background = background, viewer = NULL)
  url <- paste0("file:///", gsub("\\\\", "/", normalizePath(path)))
  webshot(url,
          file = file,
          selector = ".formattable_widget",
          delay = delay)
}

export_formattable(tbl1,"Figure2.pdf")